@@ -1,10 +1,10 @@
 use strictures 1;
 package Mojito::Template;
 BEGIN {
-  $Mojito::Template::VERSION = '0.11';
+  $Mojito::Template::VERSION = '0.12';
 }
 use Moo;
-use Mojito::Types;
+use MooX::Types::MooseLike qw(:all);
 use Mojito::Model::Link;
 use Mojito::Collection::CRUD;
 use Data::Dumper::Concise;
@@ -51,7 +51,7 @@ has 'recent_links' => (
 
 has js_css_html => (
     is => 'ro',
-    isa => Mojito::Types::NoRef,
+    isa => NoRef,
     default => sub { my $self = shift; join "\n", @{$self->javascript_html}, @{$self->css_html} }
 );
 
