@@ -1,16 +1,16 @@
 use strictures 1;
 package Mojito::Template::Role::CSS;
 BEGIN {
-  $Mojito::Template::Role::CSS::VERSION = '0.11';
+  $Mojito::Template::Role::CSS::VERSION = '0.12';
 }
 use Moo::Role;
-use Mojito::Types;
+use MooX::Types::MooseLike qw(:all);
 
 with('Mojito::Role::Config');
 
 has css => (
     is => 'ro',
-    isa => Mojito::Types::ArrayRef,
+    isa => ArrayRef,
     lazy => 1,
     builder => '_build_css',
 );
@@ -26,7 +26,7 @@ sub _build_css {
 
 has css_html => (
     is => 'ro',
-    isa => Mojito::Types::ArrayRef,
+    isa => ArrayRef,
     lazy => 1,
     builder => '_build_css_html',
 );
