@@ -1,17 +1,17 @@
 use strictures 1;
 package Mojito::Template::Role::Javascript;
 BEGIN {
-  $Mojito::Template::Role::Javascript::VERSION = '0.11';
+  $Mojito::Template::Role::Javascript::VERSION = '0.12';
 }
 use Moo::Role;
-use Mojito::Types;
+use MooX::Types::MooseLike qw(:all);
 use Data::Dumper::Concise;
 
 with('Mojito::Role::Config');
 
 has javascripts => (
     is => 'ro',
-    isa => Mojito::Types::ArrayRef,
+    isa => ArrayRef,
     lazy => 1,
     builder => '_build_javascripts',
 );
@@ -39,7 +39,7 @@ sub _build_javascripts {
 
 has javascript_html => (
     is => 'ro',
-    isa => Mojito::Types::ArrayRef,
+    isa => ArrayRef,
     lazy => 1,
     builder => '_build_javascript_html',
 );
